@@ -18,8 +18,8 @@ import sys
 from dataclasses import dataclass
 from enum import Enum
 
-from typing import Iterable, Sequence, Mapping, List, Union
-from label_sleuth.data_access.core.data_structs import Document, TextElement, Label, URI_SEP
+from typing import Iterable, Sequence, Mapping, List, Union, Set
+from label_sleuth.data_access.core.data_structs import Document, TextElement, Label, URI_SEP, LabelType
 
 
 class AlreadyExistsException(Exception):
@@ -41,8 +41,10 @@ class LabeledStatus(Enum):
 
 
 def get_document_uri(uri):
-    uri_split = uri.split(URI_SEP)
-    return URI_SEP.join(uri_split[:2])
+    """
+    get document uri from element uri
+    """
+    return uri.rsplit(URI_SEP, 1)[0]
 
 
 class DataAccessApi(object, metaclass=abc.ABCMeta):
@@ -181,7 +183,8 @@ class DataAccessApi(object, metaclass=abc.ABCMeta):
     def get_labeled_text_elements(self, workspace_id: str, dataset_name: str, category_id: int,
                                   sample_size: int = sys.maxsize,
                                   query: str = None, is_regex: bool = False,
-                                  remove_duplicates=False, random_state: int = 0) -> Mapping:
+                                  remove_duplicates=False, random_state: int = 0,
+                                  label_types: Set[LabelType] = frozenset({LabelType.Standard})) -> Mapping:
         """
         Sample *sample_size* TextElements from dataset_name, labeled for category_id in workspace_id,
         optionally limiting to those matching a query.
@@ -195,13 +198,15 @@ class DataAccessApi(object, metaclass=abc.ABCMeta):
         :param is_regex: if True, the query string is interpreted as a regular expression (False by default)
         :param remove_duplicates: if True, do not include elements that are duplicates of each other.
         :param random_state: provide an int seed to define a random state. Default is zero.
+        :param label_types: by default, only the LabelType.Standard (strong labels) retrieved.
         :return: a dictionary with two keys: 'results' whose value is a list of TextElements, and 'hit_count' whose
         value is the total number of TextElements in the dataset matched by the query.
         {'results': [TextElement], 'hit_count': int}
         """
 
     @abc.abstractmethod
-    def get_label_counts(self, workspace_id: str, dataset_name: str, category_id: int, remove_duplicates=False) \
+    def get_label_counts(self, workspace_id: str, dataset_name: str, category_id: int, remove_duplicates=False,
+                         label_types: Set[LabelType] = frozenset({LabelType.Standard})) \
             -> Mapping[bool, int]:
         """
         Return for each label value, assigned to category_id, the total count of its appearances in dataset_name.
@@ -209,6 +214,7 @@ class DataAccessApi(object, metaclass=abc.ABCMeta):
         :param dataset_name: the name of the dataset from which labels count should be generated
         :param category_id: the id of the category whose label information is the target
         :param remove_duplicates: if True, do not include elements that are duplicates of each other.
+        :param label_types: by default, only the LabelType.Standard (strong labels) retrieved.
         :return: a map whose keys are label values, and the values are the number of TextElements this label was
         assigned to.
         """
