@@ -50,7 +50,7 @@ def generate_corpus(data_access, dataset_name, num_of_documents=1, add_duplicate
     return docs
 
 
-def add_random_labels_to_document(doc: Document, min_num_sentences_to_label: int, categories: List[str], seed=0):
+def add_random_labels_to_document(doc: Document, min_num_sentences_to_label: int, categories: List[int], seed=0):
     uri_to_label = {}
     random.seed(seed)
     text_elements_to_label = random.sample(doc.text_elements, min(min_num_sentences_to_label, len(doc.text_elements)))
@@ -62,10 +62,10 @@ def add_random_labels_to_document(doc: Document, min_num_sentences_to_label: int
     return uri_to_label
 
 
-def add_labels_to_doc(doc: Document, category: str):
+def add_labels_to_doc(doc: Document, category_id: int):
     sentences_and_labels = []
     for elem in doc.text_elements:
-        labels = {category: Label(label=LABEL_POSITIVE)}
+        labels = {category_id: Label(label=LABEL_POSITIVE)}
         sentences_and_labels.append((elem.uri, labels))
     return sentences_and_labels
 
@@ -111,15 +111,15 @@ class TestFileBasedDataAccess(unittest.TestCase):
     def test_unset_labels(self):
         workspace_id = 'test_unset_labels'
         dataset_name = self.test_set_labels_and_get_documents.__name__ + '_dump'
-        category = "cat1"
+        category_id = 0
         doc = generate_corpus(self.data_access, dataset_name)[0]
-        texts_and_labels_list = add_labels_to_doc(doc, category)
+        texts_and_labels_list = add_labels_to_doc(doc, category_id)
         self.data_access.set_labels(workspace_id, dict(texts_and_labels_list))
 
-        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category)
+        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category_id)
         self.assertGreater(labels_count[True], 0)
-        self.data_access.unset_labels(workspace_id, category, [x[0] for x in texts_and_labels_list])
-        labels_count_after_unset = self.data_access.get_label_counts(workspace_id, dataset_name, category)
+        self.data_access.unset_labels(workspace_id, category_id, [x[0] for x in texts_and_labels_list])
+        labels_count_after_unset = self.data_access.get_label_counts(workspace_id, dataset_name, category_id)
         self.assertEqual(0, labels_count_after_unset[True])
         self.data_access.delete_dataset(dataset_name)
 
@@ -192,7 +192,7 @@ class TestFileBasedDataAccess(unittest.TestCase):
         docs = generate_corpus(self.data_access, dataset_name, 5)
         # add labels info for a single doc
         selected_doc = docs[0]
-        texts_and_labels_dict = dict(add_random_labels_to_document(selected_doc, 3, ['Autobots', 'Decepticons']))
+        texts_and_labels_dict = dict(add_random_labels_to_document(selected_doc, 3, [0, 1]))
         self.data_access.set_labels(workspace_id, texts_and_labels_dict)
 
         sample_and_check_that_labels_match(selected_doc, texts_and_labels_dict)
@@ -204,15 +204,15 @@ class TestFileBasedDataAccess(unittest.TestCase):
     def test_get_unlabeled_text_elements(self):
         workspace_id = 'test_sample_unlabeled_text_elements'
         dataset_name = self.test_get_unlabeled_text_elements.__name__ + '_dump'
-        category = 'Autobots'
+        category_id = 0
         sample_all = 10 ** 100  # a huge sample_size to sample all elements
         docs = generate_corpus(self.data_access, dataset_name, 2)
         # add labels info for a single doc
         selected_doc = docs[0]
-        texts_and_labels_list = add_random_labels_to_document(selected_doc, 5, [category])
+        texts_and_labels_list = add_random_labels_to_document(selected_doc, 5, [category_id])
         self.data_access.set_labels(workspace_id, texts_and_labels_list)
 
-        sampled_texts_res = self.data_access.get_unlabeled_text_elements(workspace_id, dataset_name, category,
+        sampled_texts_res = self.data_access.get_unlabeled_text_elements(workspace_id, dataset_name, category_id,
                                                                          sample_all)
         for sampled_text in sampled_texts_res['results']:
             self.assertDictEqual(sampled_text.category_to_label, {})
@@ -221,16 +221,16 @@ class TestFileBasedDataAccess(unittest.TestCase):
     def test_get_labeled_text_elements(self):
         workspace_id = 'test_sample_labeled_text_elements'
         dataset_name = self.test_get_labeled_text_elements.__name__ + '_dump'
-        category = 'Decepticons'
+        category_id = 2
         sample_all = 10 ** 100  # a huge sample_size to sample all elements
         docs = generate_corpus(self.data_access, dataset_name, 2)
         # add labels info for a single doc
         selected_doc = docs[0]
-        texts_and_labels_list = add_random_labels_to_document(selected_doc, 5, [category])
+        texts_and_labels_list = add_random_labels_to_document(selected_doc, 5, [category_id])
         self.data_access.set_labels(workspace_id, texts_and_labels_list)
         texts_and_labels_dict = dict(texts_and_labels_list)
 
-        sampled_texts_res = self.data_access.get_labeled_text_elements(workspace_id, dataset_name, category,
+        sampled_texts_res = self.data_access.get_labeled_text_elements(workspace_id, dataset_name, category_id,
                                                                        sample_all)
         self.assertEqual(len(texts_and_labels_list), len(sampled_texts_res['results']),
                          f'all and only the {len(texts_and_labels_list)} labeled elements should have been sampled.')
@@ -245,28 +245,28 @@ class TestFileBasedDataAccess(unittest.TestCase):
     def test_sample_by_query_text_elements(self):
         workspace_id = 'test_sample_by_query_text_elements'
         dataset_name = self.test_sample_by_query_text_elements.__name__ + '_dump'
-        category = 'Autobots'
+        category_id = 0
         query = 'sentence'
         sample_all = 10 ** 100  # a huge sample_size to sample all elements
         doc = generate_corpus(self.data_access, dataset_name, 1)[0]
         # doc's elements = ['Document Title is Super Interesting', 'First sentence is not that attractive.',
         #          'The second one is a bit better.', 'Last sentence offers a promising view for the future!']
         # add labels info for a single doc
-        uri_to_label_dict = {doc.text_elements[0].uri: {category: Label(label=LABEL_POSITIVE)},
+        uri_to_label_dict = {doc.text_elements[0].uri: {category_id: Label(label=LABEL_POSITIVE)},
                              # 1st sent does not match query
                              doc.text_elements[1].uri: {
-                                 category: Label(label=LABEL_POSITIVE)}}  # 2nd sent does match query
+                                 category_id: Label(label=LABEL_POSITIVE)}}  # 2nd sent does match query
 
         self.data_access.set_labels(workspace_id, uri_to_label_dict)
 
         # query + unlabeled elements
-        sampled_texts_res = self.data_access.get_unlabeled_text_elements(workspace_id, dataset_name, category,
+        sampled_texts_res = self.data_access.get_unlabeled_text_elements(workspace_id, dataset_name, category_id,
                                                                          sample_all)
         for sampled_text in sampled_texts_res['results']:
             self.assertDictEqual(sampled_text.category_to_label, {})
 
         # query + labeled elements
-        sampled_texts_res = self.data_access.get_labeled_text_elements(workspace_id, dataset_name, category, sample_all,
+        sampled_texts_res = self.data_access.get_labeled_text_elements(workspace_id, dataset_name, category_id, sample_all,
                                                                        query)
         self.assertEqual(1, len(sampled_texts_res['results']),
                          f'all and only the {len(uri_to_label_dict)} labeled elements should have been sampled.')
@@ -281,19 +281,19 @@ class TestFileBasedDataAccess(unittest.TestCase):
     def test_query_text_elements_pagination(self):
         workspace_id = 'test_sample_by_query_text_elements'
         dataset_name = self.test_sample_by_query_text_elements.__name__ + '_dump'
-        category = 'Autobots'
+        category_id = 0
         query = 'sentence'
         sample_all = 10 ** 100  # a huge sample_size to sample all elements
         generate_corpus(self.data_access, dataset_name, 5)
 
         # query no limit
-        sampled_texts_res = self.data_access.get_unlabeled_text_elements(workspace_id, dataset_name, category,
+        sampled_texts_res = self.data_access.get_unlabeled_text_elements(workspace_id, dataset_name, category_id,
                                                                          sample_all)
         self.assertEqual(20, len(sampled_texts_res['results']),
                          f"20 elements should have been sampled.")
 
         second_element_uri = sampled_texts_res["results"][1].uri
-        sampled_texts_res = self.data_access.get_unlabeled_text_elements(workspace_id, dataset_name, category,
+        sampled_texts_res = self.data_access.get_unlabeled_text_elements(workspace_id, dataset_name, category_id,
                                                                          sample_all, sample_start_idx=1)
         self.assertEqual(19, len(sampled_texts_res['results']),
                          f'19 elements should have been sampled.')
@@ -301,7 +301,7 @@ class TestFileBasedDataAccess(unittest.TestCase):
         self.assertEqual(second_element_uri, sampled_texts_res['results'][0].uri,
                          "when using sample_start_idx=1, the first element should be the second element without paging")
 
-        sampled_texts_res = self.data_access.get_unlabeled_text_elements(workspace_id, dataset_name, category,
+        sampled_texts_res = self.data_access.get_unlabeled_text_elements(workspace_id, dataset_name, category_id,
                                                                          sample_all, sample_start_idx=20)
         self.assertEqual(0, len(sampled_texts_res['results']),
                          "when sample_start_idx=number_of_elements, no element should return")
@@ -321,8 +321,8 @@ class TestFileBasedDataAccess(unittest.TestCase):
         num_docs = 100
         workspace_id = 'test_multithread_set_labels'
         dataset_name = self.test_multithread_async_set_labels.__name__ + '_dump'
-        category = 'Decepticons'
-        categories = [category]
+        category_id = 0
+        categories = [category_id]
         corpus = generate_corpus(self.data_access, dataset_name, num_of_documents=num_docs)
         batch_size = 10
 
@@ -331,7 +331,7 @@ class TestFileBasedDataAccess(unittest.TestCase):
         i = 0
         for begin in range(0, num_docs, batch_size):
             end = min(begin + batch_size, num_docs)
-            x = threading.Thread(target=self.set_labels_thread, args=(categories, category, corpus,
+            x = threading.Thread(target=self.set_labels_thread, args=(categories, category_id, corpus,
                                                                       workspace_id, begin, end, i, results))
             i += 1
             threads.append(x)
@@ -342,30 +342,29 @@ class TestFileBasedDataAccess(unittest.TestCase):
         for d in results:
             all_from_threads.update(d)
         self.assertDictEqual(dict(all_from_threads), dict(
-            self.data_access.get_label_counts(workspace_id, dataset_name, category)))
+            self.data_access.get_label_counts(workspace_id, dataset_name, category_id)))
         self.data_access.delete_dataset(dataset_name)
 
-    def set_labels_thread(self, categories, category, corpus, workspace_id, start, stop, idx, results):
+    def set_labels_thread(self, categories, category_id, corpus, workspace_id, start, stop, idx, results):
         sentences_and_labels_all = {}
         for doc in corpus[start:stop]:
             texts_and_labels_list = add_random_labels_to_document(doc, 5, categories)
             self.data_access.set_labels(workspace_id, texts_and_labels_list)
             sentences_and_labels_all.update(texts_and_labels_list)
         true_count = len(
-            [1 for _, label_dict in sentences_and_labels_all.items() if label_dict[category].label == LABEL_POSITIVE])
+            [1 for _, label_dict in sentences_and_labels_all.items() if label_dict[category_id].label == LABEL_POSITIVE])
         false_count = len(
-            [1 for _, label_dict in sentences_and_labels_all.items() if label_dict[category].label == LABEL_NEGATIVE])
+            [1 for _, label_dict in sentences_and_labels_all.items() if label_dict[category_id].label == LABEL_NEGATIVE])
         results[idx] = {LABEL_POSITIVE: true_count, LABEL_NEGATIVE: false_count}
 
     def test_get_label_counts(self):
         workspace_id = 'test_get_label_counts'
         dataset_name = self.test_get_label_counts.__name__ + '_dump'
-        category_to_count = 'Decepticons'
+        category_to_count = 2
         docs = generate_corpus(self.data_access, dataset_name, 2)
         # add labels info for a single doc
         selected_doc = docs[0]
-        uri_to_label_dict = add_random_labels_to_document(selected_doc, 5, [category_to_count, "another category 1",
-                                                                            "another category 2"])
+        uri_to_label_dict = add_random_labels_to_document(selected_doc, 5, [category_to_count, 0, 1])
         # if texts_and_labels_list:
         #     if category in texts_and_labels_list[0][1]:
         #         texts_and_labels_list[0][1][category].label = LABEL_NEGATIVE
@@ -384,7 +383,7 @@ class TestFileBasedDataAccess(unittest.TestCase):
     def test_get_text_elements_by_id(self):
         workspace_id = "test_get_text_elements_by_id"
         dataset_name = self.test_get_text_elements_by_id.__name__ + '_dump'
-        categories = ['cat_' + str(i) for i in range(3)]
+        categories = [i for i in range(3)]
         docs = generate_corpus(self.data_access, dataset_name, 2)
         doc = docs[0]
         texts_and_labels_list = add_random_labels_to_document(doc, 5, categories)  # [(uri, {category: Label})]
@@ -411,7 +410,7 @@ class TestFileBasedDataAccess(unittest.TestCase):
         workspace_id = 'test_duplicates_removal'
         dataset_name = self.test_duplicates_removal.__name__ + '_dump'
         generate_corpus(self.data_access, dataset_name, 1, add_duplicate=True)
-        category = 'cat1'
+        category_id = 0
         all_elements = sorted(self.data_access.get_all_text_elements(dataset_name),
                               key=lambda te: te.uri)
         all_elements2 = sorted(
@@ -423,41 +422,41 @@ class TestFileBasedDataAccess(unittest.TestCase):
         self.assertEqual(len(all_elements), len(all_without_dups) + 1)
 
         # 1. test propagation of labels:
-        uri_to_label_dict = {elem.uri: {category: Label(label=LABEL_POSITIVE)}
+        uri_to_label_dict = {elem.uri: {category_id: Label(label=LABEL_POSITIVE)}
                              for elem in all_without_dups}
         # set labels without propagating to duplicates
         self.data_access.set_labels(workspace_id, uri_to_label_dict, apply_to_duplicate_texts=False)
-        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category)
+        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category_id)
         self.assertEqual(labels_count[LABEL_POSITIVE], len(all_without_dups))
         # unset labels
-        self.data_access.unset_labels(workspace_id, category, [elem.uri for elem in all_without_dups])
-        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category)
+        self.data_access.unset_labels(workspace_id, category_id, [elem.uri for elem in all_without_dups])
+        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category_id)
         self.assertEqual(labels_count[LABEL_POSITIVE], 0)
         # set labels with propagating to duplicates
         self.data_access.set_labels(workspace_id, uri_to_label_dict, apply_to_duplicate_texts=True)
-        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category)
+        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category_id)
         self.assertEqual(labels_count[LABEL_POSITIVE], len(all_elements))
-        self.data_access.unset_labels(workspace_id, category, [elem.uri for elem in all_elements])
+        self.data_access.unset_labels(workspace_id, category_id, [elem.uri for elem in all_elements])
 
         # 2. test sampling of duplicate examples:
         non_representative_duplicates = [x for x in all_elements if x not in all_without_dups]
-        uri_to_label_dict = {elem.uri: {category: Label(label=LABEL_POSITIVE)}
+        uri_to_label_dict = {elem.uri: {category_id: Label(label=LABEL_POSITIVE)}
                              for elem in non_representative_duplicates}
         # set labels without propagating to duplicates
         self.data_access.set_labels(workspace_id, uri_to_label_dict, apply_to_duplicate_texts=False)
-        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category)
+        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category_id)
         sampled = \
-            self.data_access.get_labeled_text_elements(workspace_id, dataset_name, category, 10 ** 6,
+            self.data_access.get_labeled_text_elements(workspace_id, dataset_name, category_id, 10 ** 6,
                                                        remove_duplicates=True)['results']
         self.assertEqual(labels_count[LABEL_POSITIVE], len(sampled), len(non_representative_duplicates))
         # set labels with propagating to duplicates
         self.data_access.set_labels(workspace_id, uri_to_label_dict, apply_to_duplicate_texts=True)
-        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category)
+        labels_count = self.data_access.get_label_counts(workspace_id, dataset_name, category_id)
         sampled = \
-            self.data_access.get_labeled_text_elements(workspace_id, dataset_name, category, 10 ** 6,
+            self.data_access.get_labeled_text_elements(workspace_id, dataset_name, category_id, 10 ** 6,
                                                        remove_duplicates=True)['results']
         self.assertGreater(labels_count[LABEL_POSITIVE], len(non_representative_duplicates))
-        labels_count_no_dups = self.data_access.get_label_counts(workspace_id, dataset_name, category,
+        labels_count_no_dups = self.data_access.get_label_counts(workspace_id, dataset_name, category_id,
                                                                  remove_duplicates=True)
         self.assertEqual(labels_count_no_dups[LABEL_POSITIVE], len(sampled), len(non_representative_duplicates))
         self.data_access.delete_all_labels(workspace_id, dataset_name)
