@@ -31,6 +31,10 @@ class TrainingSetSelectionStrategy(Enum):
     ALL_LABELED_PLUS_UNLABELED_AS_NEGATIVE_EQUAL_RATIO = 1
     ALL_LABELED_PLUS_UNLABELED_AS_NEGATIVE_X2_RATIO = 2
     ALL_LABELED_PLUS_UNLABELED_AS_NEGATIVE_X10_RATIO = 3
+    ALL_LABELED_INCLUDE_WEAK = 4
+    ALL_LABELED_INCLUDE_WEAK_PLUS_UNLABELED_AS_NEGATIVE_EQUAL_RATIO = 5
+    ALL_LABELED_INCLUDE_WEAK_PLUS_UNLABELED_AS_NEGATIVE_X2_RATIO = 6
+    ALL_LABELED_INCLUDE_WEAK_PLUS_UNLABELED_AS_NEGATIVE_X10_RATIO = 7
 
 
 class TrainSetSelectorAPI(object, metaclass=abc.ABCMeta):
