@@ -30,8 +30,12 @@ class TrainSetSelectorAllLabeled(TrainSetSelectorAPI):
     Implements the basic model training behavior: use all elements labeled by the user - and only those elements -
     for training the model.
     """
-    def get_train_set(self, workspace_id, train_dataset_name, category_id) -> Sequence[TextElement]:
 
+    def __init__(self, data_access, label_types):
+        super().__init__(data_access)
+        self.label_types = label_types
+
+    def get_train_set(self, workspace_id, train_dataset_name, category_id) -> Sequence[TextElement]:
         train_data, train_counts = self.get_data_and_counts_for_labeled(workspace_id, train_dataset_name, category_id,
                                                                         remove_duplicates=True)
         self.verify_all_labels_are_in_train(train_counts)
@@ -44,7 +48,8 @@ class TrainSetSelectorAllLabeled(TrainSetSelectorAPI):
         labeled_elements = \
             self.data_access.get_labeled_text_elements(workspace_id=workspace_id, dataset_name=dataset_name,
                                                        category_id=category_id, sample_size=sys.maxsize,
-                                                       remove_duplicates=remove_duplicates)["results"]
+                                                       remove_duplicates=remove_duplicates,
+                                                       label_types=self.label_types)["results"]
         labels = [element.category_to_label[category_id].label for element in labeled_elements]
         counts = Counter(labels)
 
@@ -67,13 +72,13 @@ class TrainSetSelectorEnforcePositiveNegativeRatio(TrainSetSelectorAllLabeled):
     examples labeled by the user exceeds the maximal ratio, only a sample of the user-labeled negative examples
     will be sent to the model.
     """
-    def __init__(self, data_access, required_negative_ratio=None, max_negative_ratio=10**6):
+    def __init__(self, data_access, label_types, required_negative_ratio=None, max_negative_ratio=10**6):
         """
         :param data_access
         :param required_negative_ratio: required number of negative samples per positive
         :param max_negative_ratio: maximal allowed number of negative samples per positive
         """
-        super().__init__(data_access)
+        super().__init__(data_access, label_types)
         self.negative_ratio = required_negative_ratio
         self.max_negative_ratio = max_negative_ratio
         self.neg_label = LABEL_NEGATIVE
